@@ -139,8 +139,11 @@ open_database(HippoDiskCache *cache)
         "  BEGIN "
         "   DELETE FROM QueryResult WHERE query = old.id; "
         "  END ",
+        "CREATE INDEX IF NOT EXISTS Query_uriParams ON Query (uri, params)",
         "CREATE TABLE IF NOT EXISTS QueryResult (query INTEGER, resourceId TEXT)",
+        "CREATE INDEX IF NOT EXISTS QueryResult_query ON QueryResult (query)",
         "CREATE TABLE IF NOT EXISTS Property (session INTEGER, timestamp INTEGER, resourceId TEXT, propertyId TEXT, type TEXT, defaultChildren TEXT, value, itemTimestamp INTEGER DEFAULT -1)",
+        "CREATE INDEX IF NOT EXISTS Property_resourceProperty ON Property (resourceId, propertyId)",
         NULL
     };
 
@@ -943,7 +946,7 @@ _hippo_disk_cache_do_query(HippoDiskCache *cache,
     ResourceTracking *tracking;
 
     if (!hippo_sqlite_execute_sql_single_result(cache->db,
-                                  "SELECT id from Query WHERE uri = :uri AND params = :params",
+                                  "SELECT id FROM Query WHERE uri = :uri AND params = :params",
                                    "s:uri", uri,
                                    "s:params", params,
                                    NULL,
